@@ -37,7 +37,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/des/crypt.c,v 1.7 2001/08/07 00:05:00 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/des/crypt.c,v 1.7.2.2 2003/05/15 16:13:43 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <windows.h>
@@ -88,7 +88,9 @@ RCSID("$Header: /cvs/openafs/src/des/crypt.c,v 1.7 2001/08/07 00:05:00 shadow Ex
  * define "LONG_IS_32_BITS" only if sizeof(long)==4.
  * This avoids use of bit fields (your compiler may be sloppy with them).
  */
-#if !defined(cray)
+
+/* XXX shouldn't this be !AFS_64BIT_ENV ? */
+#if !defined(cray) && !defined(AFS_ALPHA_LINUX20_ENV) && !defined(AFS_IA64_LINUX20_ENV) && !defined(AFS_AMD64_LINUX20_ENV)
 #define	LONG_IS_32_BITS
 #endif
 
@@ -249,13 +251,8 @@ typedef union {
 	struct {
 #if defined(LONG_IS_32_BITS)
 		/* long is often faster than a 32-bit bit field */
-#if defined(AFS_IA64_LINUX20_ENV)
-		int	i0;
-		int	i1;
-#else
 		long	i0;
 		long	i1;
-#endif
 #else
 		long	i0: 32;
 		long	i1: 32;
