@@ -82,7 +82,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/viced/callback.c,v 1.6.2.5 2002/11/15 04:07:58 zacheiss Exp $");
+RCSID("$Header: /cvs/openafs/src/viced/callback.c,v 1.6.2.9 2003/05/15 15:51:59 shadow Exp $");
 
 #include <stdio.h> 
 #include <stdlib.h>      /* for malloc() */
@@ -442,7 +442,7 @@ static CDel(cb)
 	assert(0);
 	ViceLog(0,("CDel: Internal Error -- shutting down: wanted %d from %d, now at %d\n",cbi,fe->firstcb,*cbp));
 	DumpCallBackState();
-	ShutDown();
+	ShutDownAndCore(PANIC);
       }
     }
     CDelPtr(fe, cbp);
@@ -492,7 +492,7 @@ static u_short *FindCBPtr(fe, host)
 	if (safety > cbstuff.nblks) {
 	  ViceLog(0,("FindCBPtr: Internal Error -- shutting down.\n"));
 	  DumpCallBackState();
-	  ShutDown();
+	  ShutDownAndCore(PANIC);
 	}
 	cb = itocb(*cbp);
 	if (cb->hhead == hostindex)
@@ -695,7 +695,7 @@ AddCallBack1_r(host, fid, thead, type, locked)
 	if (safety > cbstuff.nblks) {
 	  ViceLog(0,("AddCallBack1: Internal Error -- shutting down.\n"));
 	  DumpCallBackState();
-	  ShutDown();
+	  ShutDownAndCore(PANIC);
 	}
 	if (cb->hhead == h_htoi(host))
 	    break;
@@ -819,7 +819,7 @@ static void MultiBreakCallBack_r(cba, ncbas, afidp, xhost)
 	  	ViceLog(7, 
 		  ("BCB: Failed on file %u.%d.%d, host %x.%d is down\n",
 		   afidp->AFSCBFids_val->Volume, afidp->AFSCBFids_val->Vnode,
-		   afidp->AFSCBFids_val->Unique, hp->host, hp->port));
+		   afidp->AFSCBFids_val->Unique, hp->host, ntohs(hp->port)));
 		}
 
 		H_LOCK
@@ -872,7 +872,7 @@ BreakCallBack(xhost, fid, flag)
     int hostindex;
 
     ViceLog(7,("BCB: BreakCallBack(all but %x.%d, (%u,%d,%d))\n",
-	       xhost->host, xhost->port, fid->Volume, fid->Vnode, 
+	       xhost->host, ntohs(xhost->port), fid->Volume, fid->Vnode, 
 	       fid->Unique));
 
     H_LOCK
@@ -903,7 +903,7 @@ BreakCallBack(xhost, fid, flag)
 	  }
 	  else if (thishost->hostFlags & VENUSDOWN) {
 	    ViceLog(7,("BCB: %x.%d is down; delaying break call back\n",
-		       thishost->host, thishost->port));
+		       thishost->host, ntohs(thishost->port)));
 	    cb->status = CB_DELAYED;
 	  }
 	  else {
@@ -964,7 +964,7 @@ DeleteCallBack(host, fid)
     pcb = FindCBPtr(fe, host);
     if (!*pcb) {
 	ViceLog(8,("DCB: No call back for host %x.%d, (%u, %d, %d)\n",
-	    host->host, host->port, fid->Volume, fid->Vnode, fid->Unique));
+	    host->host, ntohs(host->port), fid->Volume, fid->Vnode, fid->Unique));
 	h_Unlock_r(host);
 	H_UNLOCK
 	return;
@@ -1094,7 +1094,7 @@ int BreakDelayedCallBacks_r(host)
 	    if (ShowProblems) {
 		ViceLog(0,
 	   ("CB: Call back connect back failed (in break delayed) for %x.%d\n",
-			host->host, host->port));
+			host->host, ntohs(host->port)));
 	      }
 	    host->hostFlags |= VENUSDOWN;
 	}
@@ -1139,13 +1139,13 @@ int BreakDelayedCallBacks_r(host)
 	    if (ShowProblems) {
 		ViceLog(0,
 	     ("CB: XCallBackBulk failed, host=%x.%d; callback list follows:\n",
-		    host->host, host->port));
+		    host->host, ntohs(host->port)));
 	    }
 	    for (i = 0; i<nfids; i++) {
 		if (ShowProblems) {
 		    ViceLog(0,
 		    ("CB: Host %x.%d, file %u.%u.%u (part of bulk callback)\n",
-		               host->host, host->port, 
+		               host->host, ntohs(host->port), 
 		               fids[i].Volume, fids[i].Vnode, fids[i].Unique));
 		}
 		/* used to do this:
@@ -1196,10 +1196,10 @@ static int MultiBreakVolumeCallBack_r (host, isheld, parms)
 	    return 0;      /* Release hold */
 	}
 	ViceLog(8,("BVCB: volume call back for host %x.%d failed\n",
-		 host->host,host->port));
+		 host->host,ntohs(host->port)));
 	if (ShowProblems) {
 	    ViceLog(0, ("CB: volume callback for host %x.%d failed\n",
-		    host->host, host->port));
+		    host->host, ntohs(host->port)));
 	}
 	DeleteAllCallBacks_r(host); /* Delete all callback state rather than
 				     attempting to selectively remember to
@@ -1361,7 +1361,7 @@ CleanupTimedOutCallBacks_r()
 		if (ntimedout > cbstuff.nblks) {
 		  ViceLog(0,("CCB: Internal Error -- shutting down...\n"));
 		  DumpCallBackState();
-		  ShutDown();
+		  ShutDownAndCore(PANIC);
 		}
 	    } while (cbi != *thead);
 	    *thead = 0;
@@ -1689,7 +1689,7 @@ main(argc, argv)
     }
     if (err || argc != 1) {
 	fprintf(stderr,
-		"Usage: cbd [-host cbid] [-fid volume vnode] [-stats] callbackdumpfile\n");
+		"Usage: cbd [-host cbid] [-fid volume vnode] [-stats] [-all] callbackdumpfile\n");
 	fprintf(stderr, "[cbid is shown for each host in the hosts.dump file]\n");
 	exit(1);
     }
@@ -1812,7 +1812,9 @@ struct AFSCBFids*	afidp;
 
 	i = host->interface->numberOfInterfaces;
 	addr = malloc(i * sizeof(afs_int32));
+	if (!addr) return 1;
 	conns = malloc(i * sizeof(struct rx_connection *));
+	if (!conns) { free(addr); return 1; }
 
 	/* initialize alternate rx connections */
 	for ( i=0,j=0; i < host->interface->numberOfInterfaces; i++)
@@ -1897,7 +1899,9 @@ struct host*		host;
 
 	i = host->interface->numberOfInterfaces;
 	addr = malloc(i * sizeof(afs_int32));
+	if (!addr) return 1;
 	conns = malloc(i * sizeof(struct rx_connection *));
+	if (!conns) { free(addr); return 1; }
 
 	/* initialize alternate rx connections */
 	for ( i=0,j=0; i < host->interface->numberOfInterfaces; i++)
